# HW

## Memdumps

Idea: Dump registers from original Linux system to get device configurations.

	(for i in $(seq $((0x53fa8000)) 4 $((0x53fa9450))); do devmem2 $i; done) | tee mem.txt
	cat iomuxc_running_linux.txt | sed -n 's/Value at address \([^ ]\+\).*: \(.*\)/\1\t\2/p' > iomuxc_running_linux.tsv

Addresses:

	* iomuxc: 0x53fa8000 -> ?
	* gpio: 0x53F84000 -> 0x53FE401C

See `iomuxc_*` files and `gpio` directory for selected register dumps.

## UART

UART: UART-1, base offset 0x53FBC000

UART TX register on page 4675 of the reference manual.

## GPIO

Note that in the datasheet, and also in the DT, each gpiochip number is one higher (gpiochip0 = gpio1).

* gpiochip1,15=0 kills power to the board entirely (power back on using button on the top right)
* gpiochip4,2=1 turns on the speaker PA
* gpiochip2,15=1 turns on the debug LED
* gpiochip3,15=1 turns on power to the external USB port
* gpiochip1,26=1 turns on power to the USB Ethernet PHY

## Display

* Run and debug Sway + DRM: https://github.com/swaywm/wlroots/wiki/DRM-Debugging
	* needs `systemctl start seatd`

## Video Decode Accelerator (VPU)

* Decode with VPU
	* VPU Firmware: see above
	* ffmpeg convert with VPU: `ffmpeg -an -codec:v h264_v4l2m2m -i test.mkv -probesize 32 -c:v rawvideo -f avi out.avi`

## Firmware (SDMA, VPU, ...)

Download here: https://sources.buildroot.net/firmware-imx/
Downloaded file is SFX.

## Touch

* HW-SSn1 (gpiochip,19): CSn (for some reason, the ecSPI driver doesn't use HW SS?!?)
* gpiochip0,8: PINIRQn


# Linux Kernel

## How to load using existing U-Boot
kernel args: root=/dev/ram0 rw initrd=0x71008000,16M

Had to increase mmc read to 10 MB as the default kernel is pretty big.
Real memory size here is block count * 512B/block.

	RD_ADDR = 0x70800000 + 16*1024*1024 in hex
	RD_BLOCK = 0x800 + 16*1024*1024/512 in hex

	setenv loadaddr 0x70800000;
	setenv rdloadaddr 0x71800000;
	mmc read 0 ${loadaddr} 0x800 0x8000;
	mmc read 0 ${rdloadaddr} 0x8800 0x8000;
	bootm ${loadaddr} ${rdloadaddr}

CMDLINE=earlyprintk=serial,ttymxc0,115200 console=ttymxc0,115200 root=/dev/ram0 rd_start=70800000 rd_size=rd_start=83000000 rd_size=16777216

NOTE: Command argument passing from U-Boot does not work with the stock U-Boot.



# HW Reverse Engineering

## i2c
	[alarm@amx-tablet ~]$ sudo i2cdetect -y 0
	     0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f
	00:                         -- -- -- -- -- -- -- -- 
	10: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	20: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	30: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	40: -- -- -- -- -- -- -- -- 48 -- -- -- -- -- -- -- 
	50: 50 51 52 53 54 55 56 57 -- -- -- -- -- -- -- -- 
	60: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	70: -- -- -- -- -- -- -- --                         
	[alarm@amx-tablet ~]$ sudo i2cdetect -y 1
	     0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f
	00:                         -- -- -- -- -- -- -- -- 
	10: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	20: -- -- -- -- -- -- -- -- -- -- -- -- 2c -- -- -- 
	30: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	40: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	50: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	60: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	70: -- -- -- -- -- -- -- --                         
	[alarm@amx-tablet ~]$ sudo i2cdetect -y 2
	     0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f
	00:                         -- -- -- -- -- -- -- -- 
	10: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	20: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	30: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	40: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	50: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	60: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
	70: -- -- -- -- -- -- -- --                         
	[alarm@amx-tablet ~]$ 








# Original info

## Original cmdline

Kernel command line: console=ttymxc0,115200 video=mxcdi0fb:RGB24,bpp=32,1024x600@60 ldb=single,di=0,ch0_map=SPWG gpu_nommu gpu_memory=128M boardId=0x1A somRev=0x0 appRev=0x1 rotate=0 ethaddr=00:60:9F:9D:8D:99 root=/dev/mmcblk0p1 rootwait rw rootfstype=ext4 uboot=v2.106.42

## Orig meminfo
### cat /proc/meminfo
	MemTotal:         352320 kB
	MemFree:          292780 kB
	Buffers:            1384 kB
	Cached:            25600 kB
	SwapCached:            0 kB
	Active:            27856 kB
	Inactive:          23436 kB
	Active(anon):      24332 kB
	Inactive(anon):      204 kB
	Active(file):       3524 kB
	Inactive(file):    23232 kB
	Unevictable:           0 kB
	Mlocked:               0 kB
	HighTotal:             0 kB
	HighFree:              0 kB
	LowTotal:         352320 kB
	LowFree:          292780 kB
	SwapTotal:        538172 kB
	SwapFree:         538172 kB
	Dirty:                60 kB
	Writeback:             0 kB
	AnonPages:         24328 kB
	Mapped:            13504 kB
	Shmem:               236 kB
	Slab:               4676 kB
	SReclaimable:       1424 kB
	SUnreclaim:         3252 kB
	KernelStack:         640 kB
	PageTables:          560 kB
	NFS_Unstable:          0 kB
	Bounce:                0 kB
	WritebackTmp:          0 kB
	CommitLimit:      714332 kB
	Committed_AS:     359700 kB
	VmallocTotal:     581632 kB
	VmallocUsed:      164876 kB
	VmallocChunk:     393212 kB

### /proc/iommem
	07000000-07003fff : mxc_scc.0
	18000000-1fffffff : mxc_ipu
	20000000-20000fff : gpu_2d_registers
	30000000-3001ffff : gpu_3d_registers
	50004000-50004fff : mxsdhci.0
	  50004000-50004fff : mxsdhci
	5000c000-5000c0b5 : mxcintuart.2
	  5000c000-5000c0b5 : serial_mxc
	50010000-50010fff : mxc_spi.0
	  50010000-50010fff : mxc_spi
	50014000-5001405c : mxc_ssi.1
	50028000-50028050 : mxc_spdif.0
	5002c000-5002cfff : mxc_asrc.0
	53f80000-53f801ff : fsl-ehci.0
	  53f80000-53f801ff : ehci_hcd
	53f80200-53f803ff : fsl-ehci.1
	  53f80200-53f803ff : ehci_hcd
	53f98000-53f98030 : mxc_wdt.0
	  53f98000-53f98030 : mxc_wdt
	53fa4000-53fa4040 : mxc_rtc.0
	53fa8000-53fa8fff : mxc_ldb
	53fb4000-53fb4014 : mxc_pwm.0
	  53fb4000-53fb4014 : mxc_pwm
	53fb8000-53fb8014 : mxc_pwm.1
	  53fb8000-53fb8014 : mxc_pwm
	53fbc000-53fbc0b5 : mxcintuart.0
	  53fbc000-53fbc0b5 : serial_mxc
	53fc0000-53fc00b5 : mxcintuart.1
	  53fc0000-53fc00b5 : serial_mxc
	53fd8180-53fd81bf : mxc_dvfs_core.0
	53fec000-53fecfff : imx-i2c.2
	  53fec000-53fecfff : imx-i2c
	53ff0000-53ff00b5 : mxcintuart.3
	  53ff0000-53ff00b5 : serial_mxc
	63f90000-63f900b5 : mxcintuart.4
	  63f90000-63f900b5 : serial_mxc
	63f98000-63f9bfff : mxc_iim.0
	63fb0000-63fb0fff : mxc_sdma
	63fb4000-63fb4fff : mxc_scc.0
	63fc4000-63fc4fff : imx-i2c.1
	  63fc4000-63fc4fff : imx-i2c
	63fc8000-63fc8fff : imx-i2c.0
	  63fc8000-63fc8fff : imx-i2c
	63fcc000-63fcc05c : mxc_ssi.0
	63fec000-63fecfff : fec.0
	63ff0000-63ff0fff : tve.0
	63ff4000-63ff4fff : mxc_vpu.0
**	70000000-75ffffff : System RAM
	  70402000-70844fff : Kernel text
	  7085e000-708c19bb : Kernel data
**	76000000-7dffffff : gpu_reserved_mem
**	7e000000-7fffffff : mxc_sdc_fb.0
**	b0000000-bfffffff : System RAM
	f8020000-f805ffff : gpu_graphics_mem

### /proc/vmallocinfo 
	0x7f000000-0x7f003000   12288 module_alloc_update_bounds+0xc/0x5c pages=2 vmalloc
	0xd0800000-0xd0802000    8192 mxc_tzic_init_irq+0x10/0xec ioremap
	0xd0804000-0xd0806000    8192 mx53_clocks_init+0x24/0x63c ioremap
	0xd0808000-0xd080a000    8192 mx53_clocks_init+0x3c/0x63c ioremap
	0xd080c000-0xd080e000    8192 mx53_clocks_init+0x50/0x63c ioremap
	0xd0810000-0xd0812000    8192 mx53_clocks_init+0x64/0x63c ioremap
	0xd0814000-0xd0816000    8192 mx53_clocks_init+0x510/0x63c ioremap
	0xd0824000-0xd0826000    8192 post_cpu_init+0x38/0x180 ioremap
	0xd0828000-0xd082a000    8192 post_cpu_init+0x50/0x180 ioremap
	0xd082c000-0xd082e000    8192 post_cpu_init+0xc8/0x180 ioremap
	0xd0840000-0xd0861000  135168 iram_init+0x44/0x6c ioremap
	0xd0862000-0xd0864000    8192 mxc_pwm_probe+0x148/0x204 ioremap
	0xd0866000-0xd0868000    8192 mxc_pwm_probe+0x148/0x204 ioremap
	0xd086e000-0xd0870000    8192 sdma_probe+0x13c/0x3fc ioremap
	0xd0872000-0xd0874000    8192 mxc_spi_probe+0x218/0x5ec ioremap
	0xd0876000-0xd0878000    8192 i2c_imx_probe+0xec/0x360 ioremap
	0xd087a000-0xd087c000    8192 i2c_imx_probe+0xec/0x360 ioremap
	0xd087e000-0xd0880000    8192 i2c_imx_probe+0xec/0x360 ioremap
	0xd0882000-0xd0884000    8192 ipu_probe+0x134/0x398 ioremap
	0xd0886000-0xd0888000    8192 ipu_probe+0x148/0x398 ioremap
	0xd088a000-0xd088c000    8192 ipu_probe+0x15c/0x398 ioremap
	0xd088e000-0xd0890000    8192 ipu_probe+0x170/0x398 ioremap
	0xd0892000-0xd0894000    8192 ipu_probe+0x184/0x398 ioremap
	0xd0896000-0xd0898000    8192 ipu_probe+0x198/0x398 ioremap
	0xd089a000-0xd089c000    8192 ipu_probe+0x1ac/0x398 ioremap
	0xd089e000-0xd08a0000    8192 ipu_probe+0x1c0/0x398 ioremap
	0xd08a2000-0xd08a4000    8192 ipu_probe+0x1d4/0x398 ioremap
	0xd08a6000-0xd08a8000    8192 ipu_probe+0x1e8/0x398 ioremap
	0xd08aa000-0xd08ac000    8192 ipu_probe+0x1fc/0x398 ioremap
	0xd08ae000-0xd08b0000    8192 ipu_probe+0x210/0x398 ioremap
	0xd08b2000-0xd08b4000    8192 ipu_probe+0x250/0x398 ioremap
	0xd08b6000-0xd08b8000    8192 ipu_probe+0x264/0x398 ioremap
	0xd08be000-0xd08c0000    8192 pm_init+0x58/0x120 ioremap
	0xd08c0000-0xd08d1000   69632 ipu_probe+0x228/0x398 ioremap
	0xd08d2000-0xd08d4000    8192 pm_da9053_i2c_init+0x10/0x20 ioremap
	0xd08d6000-0xd08d8000    8192 busfreq_probe+0x34/0x458 ioremap
	0xd08da000-0xd08dc000    8192 busfreq_probe+0x48/0x458 ioremap
	0xd08de000-0xd08e0000    8192 mxc_dvfs_core_probe+0x154/0x32c ioremap
	0xd08f4000-0xd08f6000    8192 ldb_probe+0xf4/0x320 ioremap
	0xd08f8000-0xd08fd000   20480 mxc_iim_probe+0xf0/0x134 ioremap
	0xd08fe000-0xd0900000    8192 mxcuart_probe+0x68/0x140 ioremap
	0xd0900000-0xd0921000  135168 ipu_probe+0x23c/0x398 ioremap
	0xd0966000-0xd0968000    8192 mxcuart_probe+0x68/0x140 ioremap
	0xd096a000-0xd096c000    8192 mxcuart_probe+0x68/0x140 ioremap
	0xd096e000-0xd0970000    8192 mxcuart_probe+0x68/0x140 ioremap
	0xd0972000-0xd0974000    8192 mxcuart_probe+0x68/0x140 ioremap
	0xd0976000-0xd0978000    8192 usb_hcd_fsl_probe+0x144/0x3b0 ioremap
	0xd097a000-0xd097c000    8192 usb_hcd_fsl_probe+0x144/0x3b0 ioremap
	0xd097e000-0xd0980000    8192 mxc_rtc_probe+0x68/0x22c ioremap
	0xd0982000-0xd0984000    8192 mxc_wdt_probe+0x74/0x120 ioremap
	0xd0986000-0xd0988000    8192 vpu_dev_probe+0xb4/0x26c ioremap
	0xd098a000-0xd098c000    8192 mxc_asrc_probe+0xfc/0x334 ioremap
	0xd098e000-0xd0990000    8192 kgsl_hal_init+0x140/0x368 ioremap
	0xd0992000-0xd0994000    8192 sdhci_probe+0x284/0x780 ioremap
	0xd0996000-0xd0998000    8192 imx_ssi_dev_probe+0x78/0x200 ioremap
	0xd099a000-0xd099c000    8192 imx_ssi_dev_probe+0x78/0x200 ioremap
	0xd09c0000-0xd09e1000  135168 kgsl_hal_init+0x100/0x368 ioremap
	0xd09e2000-0xd0a04000  139264 sys_swapon+0x440/0xc98 pages=33 vmalloc
	0xd1000000-0xd3001000 33558528 mxcfb_probe+0x484/0x96c ioremap
	0xd4000000-0xdc001000 134221824 kgsl_hal_init+0x1fc/0x368 ioremap


## Full Original boot log

U-Boot 2009.08-svn45064 (Nov 17 2015 - 12:29:56)                                                                                                                                                     
AMX v2.106.42                                                                                                                                                                                        
                                                                                                                                                                                                     
CPU:   Freescale i.MX53 family 2.1V at 800 MHz                                                                                                                                                       
mx53 pll1: 800MHz                                                                                                                                                                                    
mx53 pll2: 400MHz                                                                                                                                                                                    
mx53 pll3: 216MHz                                                                                                                                                                                    
mx53 pll4: 455MHz                                                                                                                                                                                    
ipg clock     : 66666666Hz                                                                                                                                                                           
ipg per clock : 33333333Hz                                                                                                                                                                           
uart clock    : 66666666Hz                                                                                                                                                                           
cspi clock    : 54000000Hz                                                                                                                                                                           
ahb clock     : 133333333Hz                                                                                                                                                                          
axi_a clock   : 400000000Hz                                                                                                                                                                          
axi_b clock   : 200000000Hz                                                                                                                                                                          
emi_slow clock: 133333333Hz                                                                                                                                                                          
ddr clock     : 400000000Hz                                                                                                                                                                          
esdhc1 clock  : 80000000Hz                                                                                                                                                                           
esdhc2 clock  : 80000000Hz                                                                                                                                                                           
esdhc3 clock  : 80000000Hz                                                                                                                                                                           
esdhc4 clock  : 80000000Hz                                                                                                                                                                           
nfc clock     : 26666666Hz                                                                                                                                                                           
Board: MX53-AMX    Board ID:0x1A, SOM Rev:0x0, Board Rev:0x1                                                                                                                                         
Boot Reason: [POR]                                                                                                                                                                                   
Boot Device: SD                                                                                                                                                                                      
I2C:   ready                                                                                                                                                                                         
DRAM:  512 MB                                                                                                                                                                                        
MMC:   FSL_ESDHC: 0                                                                                                                                                                                  
Using default environment                                                                                                                                                                            
                                                                                                                                                                                                     
Checking to see if eeprom.bin exists in fat file system                                                                                                                                              
reading eeprom.bin                                                                                                                                                                                   
Calculated CRC CE21E845 -- RXed CRC CE21E845                                                                                                                                                         
                                                                                                                                                                                                     
--------------------------------------------                                                                                                                                                         
Number  of entries 5                                                                                                                                                                                 
serial_no =   226506GX21F0246                                                                                                                                                                        
ethaddr =   00:60:9F:9D:8D:99   
tchres =   1024x600                                                                                                                                                                16:13:59 [158/746]
backlight =   13622400               1024		                                                                                                                                                                
cal =   17814 0 -75437058 0 -10878 86271652 65536 0                                                                                                                                                  
Validating ethaddr extracted from eeprom.                                                                                                                                                            
macStrLen = 17, macColonCnt = 5, detectedBadMacChar = 0                                                                                                                                              
parsed MacAddr = 00 : 60 : 9f : 9d : 8d : 99                                                                                                                                                         
Validating rotate extracted from eeprom.                                                                                                                                                             
reading amx_logo_480x480s.BMP                                                                                                                                                                        
691254 bytes read                                                                                                                                                                                    
In:    serial                                                                                                                                                                                        
Out:   serial                                                                                                                                                                                        
Err:   serial                                                                                                                                                                                        
ETH out of reset...                                                                                                                                                                                  
Reseting audio codec...                                                                                                                                                                              
*************************************                                                                                                                                                                
* Changed CPU frequency to 1000 MHz *                                                                                                                                                                
*************************************                                                                                                                                                                
Net:   got MAC address: 00:60:9f:9d:8d:99                                                                                                                                                            
FEC0 [PRIME]                                                                                                                                                                                         
Hit any key to stop autoboot:  0                                                                                                                                                                     
                                                                                                                                                                                                     
MMC read: dev # 0, block # 2048, count 10240 partition # 0 ...                                                                                                                                       
10240 blocks read: OK                                                                                                                                                                                
## Booting kernel from Legacy Image at 70800000 ...                                                                                                                                                  
   Image Name:   Linux-2.6.35.3-2_106_42                                                                                                                                                             
   Image Type:   ARM Linux Kernel Image (uncompressed)                                                                                                                                               
   Data Size:    4325784 Bytes =  4.1 MB                                                                                                                                                             
   Load Address: 70008000                                                                                                                                                                            
   Entry Point:  70008000                                                                                                                                                                            
   Verifying Checksum ... OK                                                                                                                                                                         
   Loading Kernel Image ... OK                                                                                                                                                                       
OK                                                                                                                                                                                                   
                                                                                                                                                                                                     
Starting kernel ...                                                                                                                                                                                  
                                                                                                                                                                                                     
Linux version 2.6.35.3-2_106_42 (build@vm-bserver-ubuntu) (gcc version 4.4.4 (4.4.4_09.06.2010) ) #2 PREEMPT Tue Nov 17 12:34:21 CST 2015                                                            
CPU: ARMv7 Processor [412fc085] revision 5 (ARMv7), cr=10c53c7f                                                                                                                                      
CPU: VIPT nonaliasing data cache, VIPT nonaliasing instruction cache                                                                                                                                 
Machine: Freescale MX53 AMX Board                                                                                                                                                                    
Ignoring unrecognised tag 0x54410008                                                                                                                                                                 
Memory policy: ECC disabled, Data cache writeback                                                                                                                                                    
Built 1 zonelists in Zone order, mobility grouping on.  Total pages: 87552                                                                                                                           
Kernel command line: console=ttymxc0,115200 video=mxcdi0fb:RGB24,bpp=32,1024x600@60 ldb=single,di=0,ch0_map=SPWG gpu_nommu gpu_memory=128M boardId=0x1A somRev=0x0 appRev=0x1 rotate=0 ethaddr=00:60:
9F:9D:8D:99 root=/dev/mmcblk0p1 rootwait rw rootfstype=ext4 uboot=v2.106.42                                                                                                                          
(asix)early_ethaddr----MAC [00:60:9f:9d:8d:99]                                                                                                                                                       
PID hash table entries: 2048 (order: 1, 8192 bytes)                                                                                                                                                  
Dentry cache hash table entries: 65536 (order: 6, 262144 bytes)                                                                                                                                      
Inode-cache hash table entries: 32768 (order: 5, 131072 bytes)                                                                                                                                       
Memory: 96MB 256MB = 352MB total                                                                                                                                                                     
Memory: 348248k/348248k available, 12200k reserved, 0K highmem                                                                                                                                       
Virtual kernel memory layout:                                                                                                                                                                        
    vector  : 0xffff0000 - 0xffff1000   (   4 kB)                                                                                                                                                    
    fixmap  : 0xfff00000 - 0xfffe0000   ( 896 kB)                                                                                                                                                    
    DMA     : 0xf8e00000 - 0xffe00000   ( 112 MB)                                                                                                                                                    
    vmalloc : 0xd0800000 - 0xf4000000   ( 568 MB)                                                                                                                                                    
    lowmem  : 0x80000000 - 0xd0000000   (1280 MB)                                                                                                                                                    
    pkmap   : 0x7fe00000 - 0x80000000   (   2 MB)                                                                                                                                                    
    modules : 0x7f000000 - 0x7fe00000   (  14 MB)                                                                                                                                                    
      .init : 0x80008000 - 0x80402000   (4072 kB)                                                                                                                                                    
      .text : 0x80402000 - 0x80845000   (4364 kB)                                                                                                                                                    
      .data : 0x8085e000 - 0x8089cb60   ( 251 kB)                                                                                                                                                    
SLUB: Genslabs=11, HWalign=32, Order=0-3, MinObjects=0, CPUs=1, Nodes=1                                                                                                                              
Hierarchical RCU implementation.                                                                                                                                                                     
        RCU-based detection of stalled CPUs is disabled.                                                                                                                                             
        Verbose stalled-CPUs detection is disabled.                                                                                                                                                  
NR_IRQS:368                                                                                                                                                                                          
MXC GPIO hardware                                                                                                                                                                                    
MXC IRQ initialized                                                                                                                                                                                  
MXC_Early serial console at MMIO 0x53fbc000 (options '115200')                                                                                                                                       
bootconsole [ttymxc0] enabled                                                                                                                                                                        
Console: colour dummy device 80x30                                                                                                                                                                   
Calibrating delay loop... 999.42 BogoMIPS (lpj=4997120)                                                                                                                                              
pid_max: default: 32768 minimum: 301                                                                                                                                                                 
Mount-cache hash table entries: 512                                                                                                                                                                  
CPU: Testing write buffer coherency: ok                                                                                                                                                              
regulator: core version 0.5                                                                                                                                                                          
NET: Registered protocol family 16                                                                                                                                                                   
i.MX IRAM pool: 128 KB@0xd0840000                                                                                                                                                                    
IRAM READY                                                                                                                                                                                           
Initializing Board MST-701 HWID 0x190, boardId 0x1a, somRev 0x0, appRev 0x1                                                                                                                          
CPU is i.MX53 Revision 2.1                                                                                                                                                                           
got ads746 pen down GPIO                                                                                                                                                                             
Using SDMA I.API                                                                                                                                                                                     
MXC DMA API initialized                                                                                                                                                                              
IMX usb wakeup probe                                                                                                                                                                                 
IMX usb wakeup probe                                                                                                                                                                                 
bio: create slab <bio-0> at 0                                                                                                                                                                        
SCSI subsystem initialized                                                                                                                                                                           
CSPI: mxc_spi-0 probed                                                                                                                                                                               
usbcore: registered new interface driver usbfs                                                                                                                                                       
usbcore: registered new interface driver hub                                                                                                                                                         
usbcore: registered new device driver usb                                                                                                                                                            
Entered da9052_i2c_is_connected.............                                                                                                                                                         
da9052_i2c_is_connected - i2c read success..............                                                                                                                                             
regulator: DA9052_LDO1: 600 <--> 1800 mV at 1300 mV normal                                                                                                                                           
regulator: DA9052_LDO2: 600 <--> 1800 mV at 1300 mV normal                                                                                                                                           
regulator: DA9052_LDO3: 1725 <--> 3300 mV at 3300 mV normal                                                                                                                                          
regulator: DA9052_LDO4: 1725 <--> 3300 mV at 2775 mV normal                                                                                                                                          
regulator: DA9052_LDO5: 1200 <--> 3600 mV at 1300 mV normal                                                                                                                                          
regulator: DA9052_LDO6: 1200 <--> 3600 mV at 1300 mV normal                                                                                                                                          
regulator: DA9052_LDO7: 1200 <--> 3600 mV at 2750 mV normal                                                                                                                                          
regulator: DA9052_LDO8: 1200 <--> 3600 mV at 1800 mV normal                                                                                                                                          
regulator: DA9052_LDO9: 1250 <--> 3650 mV at 1500 mV normal                                                                                                                                          
regulator: DA9052_LDO10: 1200 <--> 3600 mV at 1300 mV normal                                                                                                                                         
regulator: DA9052_BUCK_CORE: 500 <--> 2075 mV at 1250 mV normal                                                                                                                                      
regulator: DA9052_BUCK_PRO: 500 <--> 2075 mV at 1300 mV normal                                                                                                                                       
regulator: DA9052_BUCK_MEM: 925 <--> 2500 mV at 1175 mV normal                                                                                                                                       
regulator: DA9052_BUCK_PERI: 1800 <--> 3600 mV at 3600 mV normal                                                                                                                                     
DA9053 chip ID reg read=0xb3                                                                                                                                                                         
unknown chip version                                                                                                                                                                                 
IPU DMFC NORMAL mode: 1(0~1), 5B(4,5), 5F(6,7)                                                                                                                                                       
Advanced Linux Sound Architecture Driver Version 1.0.23.                                                                                                                                             
Bluetooth: Core ver 2.15                                                                                                                                                                             
NET: Registered protocol family 31                                                                                                                                                                   
Bluetooth: HCI device and connection manager initialized                                                                                                                                             
Bluetooth: HCI socket layer initialized                                                                                                                                                              
Switching to clocksource mxc_timer1                                                                                                                                                                  
NET: Registered protocol family 2                                                                                                                                                                    
IP route cache hash table entries: 4096 (order: 2, 16384 bytes)                                                                                                                                      
TCP established hash table entries: 16384 (order: 5, 131072 bytes)                                                                                                                                   
TCP bind hash table entries: 16384 (order: 4, 65536 bytes)                                                                                                                                           
TCP: Hash tables configured (established 16384 bind 16384)                                                                                                                                           
TCP reno registered                                                                                                                                                                                  
UDP hash table entries: 256 (order: 0, 4096 bytes)                                                                                                                                                   
UDP-Lite hash table entries: 256 (order: 0, 4096 bytes)                                                                                                                                              
NET: Registered protocol family 1                                                                                                                                                                    
RPC: Registered udp transport module.                                                                                                                                                                
RPC: Registered tcp transport module.                                                                                                                                                                
RPC: Registered tcp NFSv4.1 backchannel transport module.                                                                                                                                            
LPMode driver module loaded                                                                                                                                                                          
Static Power Management for Freescale i.MX5                                                                                                                                                          
PM driver module loaded                                                                                                                                                                              
sdram autogating driver module loaded                                                                                                                                                                
Bus freq driver module loaded                                                                                                                                                                        
AMX-FB-UW using DI0. BG->/dev/fb0 FG->/dev/fb2                                                                                                                                                       
mxc_dvfs_core_probe                                                                                                                                                                                  
DVFS driver module loaded                                                                                                                                                                            
i.MXC CPU frequency driver                                                                                                                                                                           
DVFS PER driver module loaded                                                                                                                                                                        
msgmni has been set to 680                                                                                                                                                                           
alg: No test for stdrng (krng)                                                                                                                                                                       
cryptodev: driver loaded.                                                                                                                                                                            
io scheduler noop registered                                                                                                                                                                         
io scheduler deadline registered                                                                                                                                                                     
io scheduler cfq registered (default)                                                                                                                                                                
regulator: get() with no identifier                                                                                                                                                                  
ldb_fb_pre_setup: ldb_clk_prtate fixup!                                                                                                                                                              
mxc_ipu mxc_ipu: Channel already disabled 9                                                                                                                                                          
mxc_ipu mxc_ipu: Channel already uninitialized 9                                                                                                                                                     
IPU DMFC DP HIGH RESOLUTION: 1(0,1), 5B(2~5), 5F(6,7)                                                                                                                                                
mxc_ipu mxc_ipu: Channel already disabled 7                                                                                                                                                          
mxc_ipu mxc_ipu: Channel already uninitialized 7         
mxc_ipu mxc_ipu: Channel already disabled 10
mxc_ipu mxc_ipu: Channel already uninitialized 10
Serial: MXC Internal UART driver
mxcintuart.0: ttymxc0 at MMIO 0x53fbc000 (irq = 31) is a Freescale i.MX
console [ttymxc0] enabled, bootconsole disabled
console [ttymxc0] enabled, bootconsole disabled
mxcintuart.1: ttymxc1 at MMIO 0x53fc0000 (irq = 32) is a Freescale i.MX
mxcintuart.2: ttymxc2 at MMIO 0x5000c000 (irq = 33) is a Freescale i.MX
mxcintuart.3: ttymxc3 at MMIO 0x53ff0000 (irq = 13) is a Freescale i.MX
mxcintuart.4: ttymxc4 at MMIO 0x63f90000 (irq = 86) is a Freescale i.MX
brd: module loaded
loop: module loaded
ad_dpot 1-002f: ad5243 256-Position Digital Potentiometer registered
ad_dpot 1-002c: ad5245 256-Position Digital Potentiometer registered
usbcore: registered new interface driver asix
ehci_hcd: USB 2.0 'Enhanced' Host Controller (EHCI) Driver
fsl-ehci fsl-ehci.0: Freescale On-Chip EHCI Host Controller
fsl-ehci fsl-ehci.0: new USB bus registered, assigned bus number 1
fsl-ehci fsl-ehci.0: irq 18, io base 0x53f80000
fsl-ehci fsl-ehci.0: USB 2.0 started, EHCI 1.00
usb usb1: New USB device found, idVendor=1d6b, idProduct=0002
usb usb1: New USB device strings: Mfr=3, Product=2, SerialNumber=1
usb usb1: Product: Freescale On-Chip EHCI Host Controller
usb usb1: Manufacturer: Linux 2.6.35.3-2_106_42 ehci_hcd
usb usb1: SerialNumber: fsl-ehci.0
hub 1-0:1.0: USB hub found
hub 1-0:1.0: 1 port detected
fsl-ehci fsl-ehci.1: Freescale On-Chip EHCI Host Controller
fsl-ehci fsl-ehci.1: new USB bus registered, assigned bus number 2
fsl-ehci fsl-ehci.1: irq 14, io base 0x53f80200
fsl-ehci fsl-ehci.1: USB 2.0 started, EHCI 1.00
usb usb2: New USB device found, idVendor=1d6b, idProduct=0002
usb usb2: New USB device strings: Mfr=3, Product=2, SerialNumber=1
usb usb2: Product: Freescale On-Chip EHCI Host Controller
usb usb2: Manufacturer: Linux 2.6.35.3-2_106_42 ehci_hcd
usb usb2: SerialNumber: fsl-ehci.1
hub 2-0:1.0: USB hub found
hub 2-0:1.0: 1 port detected
Initializing USB Mass Storage driver...
usbcore: registered new interface driver usb-storage
USB Mass Storage support registered.
mice: PS/2 mouse device common for all mice
input: gpio-keys as /devices/platform/gpio-keys/input/input0
ads7846 spi1.1: touchscreen, irq 136
input: ADS7846 Touchscreen as /devices/platform/mxc_spi.0/spi1.1/input/input1
mxc_rtc mxc_rtc.0: rtc core: registered mxc_rtc as rtc0
i2c /dev entries driver
Linux video capture interface: v2.00
mxc_v4l2_output mxc_v4l2_output.0: Registered device video0
MXC WatchDog Driver 2.0
MXC Watchdog # 0 Timer: initial timeout 60 sec
Bluetooth: Virtual HCI driver ver 1.3
Bluetooth: HCI UART driver ver 2.2
Bluetooth: Generic Bluetooth USB driver ver 0.6
usbcore: registered new interface driver btusb
VPU initialized
mxc_asrc registered
gpu mmu disabled
mxsdhci: MXC Secure Digital Host Controller Interface driver
mxsdhci: MXC SDHCI Controller Driver. 
mmc0: SDHCI detect irq 0 irq 1 INTERNAL DMA
usbcore: registered new interface driver hiddev
usbcore: registered new interface driver usbhid
usbhid: USB HID core driver

sgtl5000_i2c_probe: board_id = 0x1a
sgtl5000-i2c 1-000a: SGTL5000 revision 17
No device for DAI imx-ssi-1-0
No device for DAI imx-ssi-1-1
No device for DAI imx-ssi-2-0
No device for DAI imx-ssi-2-1
usb 2-1: new high speed USB device using fsl-ehci and address 2
capture=0 ext_ram=0 UseIram=1
DMA Sound Buffers Allocated:UseIram=1 buf->addr=f8016000 buf->area=d0856000 size=24576
capture=1 ext_ram=0 UseIram=1
DMA Sound Buffers Allocated:UseIram=1 buf->addr=bf6f8000 buf->area=f8eea000 size=24576
asoc: SGTL5000 <-> imx-ssi-2-0 mapping ok
mmc0: new high speed SDHC card at address b368
mmcblk0: mmc0:b368       3.73 GiB 
 mmcblk0: p1 p2 p3 < p5 p6 p7 > p4
ALSA device list:
  #0: imx-3stack (SGTL5000)
TCP cubic registered
NET: Registered protocol family 17
Bluetooth: L2CAP ver 2.14
Bluetooth: L2CAP socket layer initialized
Bluetooth: SCO (Voice Link) ver 0.6
Bluetooth: SCO socket layer initialized
Bluetooth: RFCOMM TTY layer initialized
Bluetooth: RFCOMM socket layer initialized
Bluetooth: RFCOMM ver 1.11
Bluetooth: BNEP (Ethernet Emulation) ver 1.3
Bluetooth: BNEP filters: protocol multicast
Bluetooth: HIDP (Human Interface Emulation) ver 1.2
802.1Q VLAN Support v1.8 Ben Greear <greearb@candelatech.com>
All bugs added by David S. Miller <davem@redhat.com>
VFP support v0.3: implementor 41 architecture 3 part 30 variant c rev 2
usb 2-1: New USB device found, idVendor=0b95, idProduct=772b
usb 2-1: New USB device strings: Mfr=1, Product=2, SerialNumber=3
regulator_init_complete: incomplete constraints, leaving DA9052_BUCK_PERI on
regulator_init_complete: incomplete constraints, leaving DA9052_BUCK_MEM on
regulator_init_complete: incomplete constraints, leaving DA9052_BUCK_PRO on
regulator_init_complete: incomplete constraints, leaving DA9052_BUCK_CORE on
regulator_init_complete: incomplete constraints, leaving DA9052_LDO10 on
regulator_init_complete: incomplete constraints, leaving DA9052_LDO9 on
regulator_init_complete: incomplete constraints, leaving DA9052_LDO8 on
regulator_init_complete: incomplete constraints, leaving DA9052_LDO7 on
regulator_init_complete: incomplete constraints, leaving DA9052_LDO6 on
regulator_init_complete: incomplete constraints, leaving DA9052_LDO5 on
regulator_init_complete: incomplete constraints, leaving DA9052_LDO4 on
regulator_init_complete: incomplete constraints, leaving DA9052_LDO3 on
regulator_init_complete: incomplete constraints, leaving DA9052_LDO2 on
regulator_init_complete: incomplete constraints, leaving DA9052_LDO1 on
mxc_rtc mxc_rtc.0: setting system clock to 1970-01-01 00:00:00 UTC (0)
Freeing init memory: 4072K
usb 2-1: Product: AX88772B
usb 2-1: Manufacturer: ASIX Elec. Corp.
usb 2-1: SerialNumber: 000001

*******************************************
*   Starting System Init for iMX5X        *
*******************************************
asix 2-1:1.0: (unregistered net_device): ax88772_bind() flags 860, urbsize: 16384
asix 2-1:1.0: eth0: register 'asix' at usb-fsl-ehci.1-1, ASIX AX88772 USB 2.0 Ethernet, 00:60:9f:9d:8d:99
ROOTFS: recovering journal
ROOTFS: Superblock last mount time is in the future.  FIXED.
ROOTFS: clean, 2378/68544 files, 106571/273104 blocks (check in 2 mounts)
OPTFS: recovering journal
OPTFS: Superblock last mount time is in the future.  FIXED.
OPTFS: clean, 2921/176352 files, 61998/704851 blocks (check in 4 mounts)
UTILFS: Superblock last mount time is in the future.  FIXED.
UTILFS: Superblock last write time is in the future.  FIXED.
UTILFS: clean, 34/20080 files, 9350/80292 blocks (check after next mount)
RECOVERYFS: clean, 13/28112 files, 67686/112420 blocks (check after next mount)
EXT4-fs (mmcblk0p4): mounted filesystem with ordered data mode. Opts: 
EXT4-fs (mmcblk0p6): mounted filesystem with ordered data mode. Opts: (null)
5 second timeout exeeded.
5 second timeout exeeded.
Boot Progress Display: starting.
Modero S: No sensors to upgrade
EXT4-fs (mmcblk0p1): mounted filesystem with ordered data mode. Opts: (null)
udevd[1204]: error: runtime directory '/run/udev' not writable, for now falling back to '/dev/.udev'
at24 0-0050: 256 byte 24c02 EEPROM (writable)
EXT4-fs (mmcblk0p1): re-mounted. Opts: (null)
EXT4-fs (mmcblk0p4): mounted filesystem with ordered data mode. Opts: (null)
Adding 538172k swap on /dev/mmcblk0p2.  Priority:-1 extents:1 across:538172k SS
eth0: link up, 100Mbps, full-duplex, lpa 0xCDE1
INIT: Entering runlevel: 3
Removing stale PID file /usr/var/run/dbus/pid.
Starting system message bus: dbus.

localhost login: 
